@@ -1,12 +1,12 @@
 // Predefined symbols and macros -*- C++ -*-
 
 // Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
-// 2006, 2007 Free Software Foundation, Inc.
+// 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
 // terms of the GNU General Public License as published by the
-// Free Software Foundation; either version 2, or (at your option)
+// Free Software Foundation; either version 3, or (at your option)
 // any later version.
 
 // This library is distributed in the hope that it will be useful,
@@ -14,19 +14,14 @@
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 
-// You should have received a copy of the GNU General Public License along
-// with this library; see the file COPYING.  If not, write to the Free
-// Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-// USA.
+// Under Section 7 of GPL version 3, you are granted additional
+// permissions described in the GCC Runtime Library Exception, version
+// 3.1, as published by the Free Software Foundation.
 
-// As a special exception, you may use this file as part of a free software
-// library without restriction.  Specifically, if other files instantiate
-// templates or use macros or inline functions from this file, or you compile
-// this file and link it with other files to produce an executable, this
-// file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however
-// invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.
+// You should have received a copy of the GNU General Public License and
+// a copy of the GCC Runtime Library Exception along with this program;
+// see the files COPYING3 and COPYING.RUNTIME respectively.  If not, see
+// <http://www.gnu.org/licenses/>.
 
 /** @file c++config.h
  *  This is an internal header file, included by other library headers.
@@ -36,14 +31,8 @@
 #ifndef _GLIBCXX_CXX_CONFIG_H
 #define _GLIBCXX_CXX_CONFIG_H 1
 
-// Pick up any OS-specific definitions.
-#include <bits/os_defines.h>
-
-// Pick up any CPU-specific definitions.
-#include <bits/cpu_defines.h>
-
 // The current version of the C++ library in compressed ISO date format.
-#define __GLIBCXX__ 20100522 
+#define __GLIBCXX__ 20100429 
 
 // Macros for visibility.
 // _GLIBCXX_HAVE_ATTRIBUTE_VISIBILITY
@@ -86,6 +75,7 @@
     namespace tr1 { }
   }
 */
+#if __cplusplus
 
 #ifdef _GLIBCXX_DEBUG
 # define _GLIBCXX_NAMESPACE_ASSOCIATION_DEBUG 1
@@ -109,15 +99,12 @@
 // _GLIBCXX_STD
 // _GLIBCXX_STD_D
 // _GLIBCXX_STD_P
-
 //
 // Macros for enclosing namespaces and possibly nested namespaces.
 // _GLIBCXX_BEGIN_NAMESPACE
 // _GLIBCXX_END_NAMESPACE
 // _GLIBCXX_BEGIN_NESTED_NAMESPACE
 // _GLIBCXX_END_NESTED_NAMESPACE
-// _GLIBCXX_BEGIN_POTENTIAL_NESTED_NAMESPACE
-// _GLIBCXX_END_POTENTIAL_NESTED_NAMESPACE
 #ifndef _GLIBCXX_USE_NAMESPACE_ASSOCIATION
 # define _GLIBCXX_STD_D _GLIBCXX_STD
 # define _GLIBCXX_STD_P _GLIBCXX_STD
@@ -143,7 +130,7 @@
 #  define _GLIBCXX_STD __cxx1998
 #  define _GLIBCXX_BEGIN_NAMESPACE(X) namespace X _GLIBCXX_VISIBILITY_ATTR(default) { 
 #  define _GLIBCXX_END_NAMESPACE }
-#  define _GLIBCXX_EXTERN_TEMPLATE 0
+#  define _GLIBCXX_EXTERN_TEMPLATE -1
 # endif
 
 // parallel
@@ -153,7 +140,7 @@
 #  define _GLIBCXX_STD __cxx1998
 #  define _GLIBCXX_BEGIN_NAMESPACE(X) namespace X _GLIBCXX_VISIBILITY_ATTR(default) { 
 #  define _GLIBCXX_END_NAMESPACE }
-#  define _GLIBCXX_EXTERN_TEMPLATE 0
+#  define _GLIBCXX_EXTERN_TEMPLATE -1
 # endif
 
 // debug + parallel
@@ -163,7 +150,7 @@
 #  define _GLIBCXX_STD __cxx1998
 #  define _GLIBCXX_BEGIN_NAMESPACE(X) namespace X _GLIBCXX_VISIBILITY_ATTR(default) { 
 #  define _GLIBCXX_END_NAMESPACE }
-#  define _GLIBCXX_EXTERN_TEMPLATE 0
+#  define _GLIBCXX_EXTERN_TEMPLATE -1
 # endif
 
 # if __NO_INLINE__ && !__GXX_WEAK__
@@ -180,11 +167,8 @@
 namespace std
 { 
   namespace __norm { } 
-  namespace __debug { }
-  namespace __cxx1998 { }
-
-  using namespace __debug __attribute__ ((strong)); 
-  using namespace __cxx1998 __attribute__ ((strong)); 
+  inline namespace __debug { }
+  inline namespace __cxx1998 { }
 }
 #endif
 
@@ -193,11 +177,8 @@ namespace std
 namespace std
 { 
   namespace __norm { } 
-  namespace __parallel { }
-  namespace __cxx1998 { }
-
-  using namespace __parallel __attribute__ ((strong));
-  using namespace __cxx1998 __attribute__ ((strong)); 
+  inline namespace __parallel { }
+  inline namespace __cxx1998 { }
 }
 #endif
 
@@ -205,46 +186,65 @@ namespace std
 #if _GLIBCXX_NAMESPACE_ASSOCIATION_VERSION
 namespace std
 {
-  namespace _6 { }
-  using namespace _6 __attribute__ ((strong));
+  inline namespace _6 { }
 }
 
 namespace __gnu_cxx 
 { 
-  namespace _6 { }
-  using namespace _6 __attribute__ ((strong));
+  inline namespace _6 { }
 }
 
 namespace std
 {
   namespace tr1 
   { 
-    namespace _6 { }
-    using namespace _6 __attribute__ ((strong));
+    inline namespace _6 { }
   }
 }
 #endif
 
-// Define if compatibility should be provided for -mlong-double-64.
+// XXX GLIBCXX_ABI Deprecated
+// Define if compatibility should be provided for -mlong-double-64
 #undef _GLIBCXX_LONG_DOUBLE_COMPAT
 
-// XXX GLIBCXX_ABI Deprecated
 // Namespace associations for long double 128 mode.
-_GLIBCXX_BEGIN_NAMESPACE(std)
-#if defined _GLIBCXX_LONG_DOUBLE_COMPAT && defined __LONG_DOUBLE_128__
+#if defined _GLIBCXX_LONG_DOUBLE_COMPAT && defined __LONG_DOUBLE_128__ 
+namespace std
+{
+  inline namespace __gnu_cxx_ldbl128 { }
+}
 # define _GLIBCXX_LDBL_NAMESPACE __gnu_cxx_ldbl128::
 # define _GLIBCXX_BEGIN_LDBL_NAMESPACE namespace __gnu_cxx_ldbl128 {
 # define _GLIBCXX_END_LDBL_NAMESPACE }
-  namespace __gnu_cxx_ldbl128 { }
-  using namespace __gnu_cxx_ldbl128 __attribute__((__strong__));
 #else
 # define _GLIBCXX_LDBL_NAMESPACE
 # define _GLIBCXX_BEGIN_LDBL_NAMESPACE
 # define _GLIBCXX_END_LDBL_NAMESPACE
 #endif
-_GLIBCXX_END_NAMESPACE
 
 
+// Defines for C compatibility. In particular, define extern "C"
+// linkage only when using C++.
+# define _GLIBCXX_BEGIN_EXTERN_C extern "C" {
+# define _GLIBCXX_END_EXTERN_C }
+
+#else // !__cplusplus
+# undef _GLIBCXX_BEGIN_NAMESPACE
+# undef _GLIBCXX_END_NAMESPACE
+# define _GLIBCXX_BEGIN_NAMESPACE(X) 
+# define _GLIBCXX_END_NAMESPACE 
+# define _GLIBCXX_BEGIN_EXTERN_C
+# define _GLIBCXX_END_EXTERN_C 
+#endif
+
+// First includes.
+
+// Pick up any OS-specific definitions.
+#include <bits/os_defines.h>
+
+// Pick up any CPU-specific definitions.
+#include <bits/cpu_defines.h>
+
 // Allow use of "export template." This is currently not a feature
 // that g++ supports.
 // #define _GLIBCXX_EXPORT_TEMPLATE 1
@@ -259,7 +259,6 @@ _GLIBCXX_END_NAMESPACE
 # define _GLIBCXX_EXTERN_TEMPLATE 1
 #endif
 
-
 // Certain function definitions that are meant to be overridable from
 // user code are decorated with this macro.  For some targets, this
 // macro causes these definitions to be weak.
@@ -267,12 +266,32 @@ _GLIBCXX_END_NAMESPACE
 # define _GLIBCXX_WEAK_DEFINITION
 #endif
 
-// Macro used to indicate that the native "C" includes, when compiled
-// as "C++", have declarations in namespace std and not the global
-// namespace. Note, this is unrelated to possible "C" compatibility
-// includes that inject C90/C99 names into the global namespace.
-#if __cplusplus == 199711L
-# define _GLIBCXX_NAMESPACE_GLOBAL_INJECTION 1
+// Assert.
+// Avoid the use of assert, because we're trying to keep the <cassert>
+// include out of the mix.
+#if !defined(_GLIBCXX_DEBUG) && !defined(_GLIBCXX_PARALLEL)
+#define __glibcxx_assert(_Condition)
+#else
+_GLIBCXX_BEGIN_NAMESPACE(std)
+  // Avoid the use of assert, because we're trying to keep the <cassert>
+  // include out of the mix.
+  inline void
+  __replacement_assert(const char* __file, int __line, 
+		       const char* __function, const char* __condition)
+  {
+    __builtin_printf("%s:%d: %s: Assertion '%s' failed.\n", __file, __line,
+		     __function, __condition);
+    __builtin_abort();
+  }
+_GLIBCXX_END_NAMESPACE
+
+#define __glibcxx_assert(_Condition)                               	\
+  do 								        \
+  {							      		\
+    if (! (_Condition))                                                 \
+      std::__replacement_assert(__FILE__, __LINE__, 			\
+				__PRETTY_FUNCTION__, #_Condition);	\
+  } while (false)
 #endif
 
 // The remainder of the prewritten config is automatic; all the
@@ -311,6 +330,9 @@ _GLIBCXX_END_NAMESPACE
 /* Define to 1 if you have the `asinl' function. */
 #define _GLIBCXX_HAVE_ASINL 1
 
+/* Define to 1 if the target assembler supports .symver directive. */
+#define _GLIBCXX_HAVE_AS_SYMVER_DIRECTIVE 1
+
 /* Define to 1 if you have the `atan2f' function. */
 #define _GLIBCXX_HAVE_ATAN2F 1
 
@@ -335,15 +357,6 @@ _GLIBCXX_END_NAMESPACE
 /* Define to 1 if you have the <complex.h> header file. */
 #define _GLIBCXX_HAVE_COMPLEX_H 1
 
-/* Define to 1 if you have the `copysign' function. */
-#define _GLIBCXX_HAVE_COPYSIGN 1
-
-/* Define to 1 if you have the `copysignf' function. */
-#define _GLIBCXX_HAVE_COPYSIGNF 1
-
-/* Define to 1 if you have the `copysignl' function. */
-#define _GLIBCXX_HAVE_COPYSIGNL 1
-
 /* Define to 1 if you have the `cosf' function. */
 #define _GLIBCXX_HAVE_COSF 1
 
@@ -359,9 +372,51 @@ _GLIBCXX_END_NAMESPACE
 /* Define to 1 if you have the <dlfcn.h> header file. */
 #define _GLIBCXX_HAVE_DLFCN_H 1
 
+/* Define if EBADMSG exists. */
+#define _GLIBCXX_HAVE_EBADMSG 1
+
+/* Define if ECANCELED exists. */
+#define _GLIBCXX_HAVE_ECANCELED 1
+
+/* Define if EIDRM exists. */
+#define _GLIBCXX_HAVE_EIDRM 1
+
 /* Define to 1 if you have the <endian.h> header file. */
 #define _GLIBCXX_HAVE_ENDIAN_H 1
 
+/* Define if ENODATA exists. */
+#define _GLIBCXX_HAVE_ENODATA 1
+
+/* Define if ENOLINK exists. */
+#define _GLIBCXX_HAVE_ENOLINK 1
+
+/* Define if ENOSR exists. */
+#define _GLIBCXX_HAVE_ENOSR 1
+
+/* Define if ENOSTR exists. */
+#define _GLIBCXX_HAVE_ENOSTR 1
+
+/* Define if ENOTRECOVERABLE exists. */
+#define _GLIBCXX_HAVE_ENOTRECOVERABLE 1
+
+/* Define if ENOTSUP exists. */
+#define _GLIBCXX_HAVE_ENOTSUP 1
+
+/* Define if EOVERFLOW exists. */
+#define _GLIBCXX_HAVE_EOVERFLOW 1
+
+/* Define if EOWNERDEAD exists. */
+#define _GLIBCXX_HAVE_EOWNERDEAD 1
+
+/* Define if EPROTO exists. */
+#define _GLIBCXX_HAVE_EPROTO 1
+
+/* Define if ETIME exists. */
+#define _GLIBCXX_HAVE_ETIME 1
+
+/* Define if ETXTBSY exists. */
+#define _GLIBCXX_HAVE_ETXTBSY 1
+
 /* Define to 1 if you have the `expf' function. */
 #define _GLIBCXX_HAVE_EXPF 1
 
@@ -413,18 +468,9 @@ _GLIBCXX_END_NAMESPACE
 /* Define to 1 if you have the `frexpl' function. */
 #define _GLIBCXX_HAVE_FREXPL 1
 
-/* Define to 1 if you have the <gconf.h> header file. */
-/* #undef _GLIBCXX_HAVE_GCONF_H */
-
-/* Define to 1 if you have the <gconv.h> header file. */
-#define _GLIBCXX_HAVE_GCONV_H 1
-
 /* Define if _Unwind_GetIPInfo is available. */
 #define _GLIBCXX_HAVE_GETIPINFO 1
 
-/* Define to 1 if you have the `getpagesize' function. */
-#define _GLIBCXX_HAVE_GETPAGESIZE 1
-
 /* Define if gthr-default.h exists (meaning that threading support is
    enabled). */
 #define _GLIBCXX_HAVE_GTHR_DEFAULT 1
@@ -447,6 +493,12 @@ _GLIBCXX_END_NAMESPACE
 /* Define if int64_t is available in <stdint.h>. */
 #define _GLIBCXX_HAVE_INT64_T 1
 
+/* Define if int64_t is a long. */
+/* #undef _GLIBCXX_HAVE_INT64_T_LONG */
+
+/* Define if int64_t is a long long. */
+#define _GLIBCXX_HAVE_INT64_T_LONG_LONG 1
+
 /* Define to 1 if you have the <inttypes.h> header file. */
 #define _GLIBCXX_HAVE_INTTYPES_H 1
 
@@ -483,9 +535,6 @@ _GLIBCXX_END_NAMESPACE
 /* Define to 1 if you have the <libintl.h> header file. */
 /* #undef _GLIBCXX_HAVE_LIBINTL_H */
 
-/* Define to 1 if you have the `m' library (-lm). */
-#define _GLIBCXX_HAVE_LIBM 1
-
 /* Only used in build directory testsuite_hooks.h. */
 #define _GLIBCXX_HAVE_LIMIT_AS 1
 
@@ -531,9 +580,6 @@ _GLIBCXX_END_NAMESPACE
 /* Define to 1 if you have the <memory.h> header file. */
 #define _GLIBCXX_HAVE_MEMORY_H 1
 
-/* Define to 1 if you have a working `mmap' system call. */
-#define _GLIBCXX_HAVE_MMAP 1
-
 /* Define to 1 if you have the `modf' function. */
 #define _GLIBCXX_HAVE_MODF 1
 
@@ -561,9 +607,6 @@ _GLIBCXX_END_NAMESPACE
 /* Define to 1 if you have the `setenv' function. */
 #define _GLIBCXX_HAVE_SETENV 1
 
-/* Define if sigsetjmp is available. */
-#define _GLIBCXX_HAVE_SIGSETJMP 1
-
 /* Define to 1 if you have the `sincos' function. */
 #define _GLIBCXX_HAVE_SINCOS 1
 
@@ -637,7 +680,7 @@ _GLIBCXX_END_NAMESPACE
 /* #undef _GLIBCXX_HAVE_SYS_MACHINE_H */
 
 /* Define to 1 if you have the <sys/param.h> header file. */
-/* #undef _GLIBCXX_HAVE_SYS_PARAM_H */
+#define _GLIBCXX_HAVE_SYS_PARAM_H 1
 
 /* Define to 1 if you have the <sys/resource.h> header file. */
 #define _GLIBCXX_HAVE_SYS_RESOURCE_H 1
@@ -735,12 +778,6 @@ _GLIBCXX_END_NAMESPACE
 /* Define to 1 if you have the `_ceill' function. */
 /* #undef _GLIBCXX_HAVE__CEILL */
 
-/* Define to 1 if you have the `_copysign' function. */
-/* #undef _GLIBCXX_HAVE__COPYSIGN */
-
-/* Define to 1 if you have the `_copysignl' function. */
-/* #undef _GLIBCXX_HAVE__COPYSIGNL */
-
 /* Define to 1 if you have the `_cosf' function. */
 /* #undef _GLIBCXX_HAVE__COSF */
 
@@ -897,57 +934,6 @@ _GLIBCXX_END_NAMESPACE
 /* Define to 1 if you have the `_tanl' function. */
 /* #undef _GLIBCXX_HAVE__TANL */
 
-/* Define if the compiler/host combination has __builtin_abs. */
-#define _GLIBCXX_HAVE___BUILTIN_ABS 1
-
-/* Define if the compiler/host combination has __builtin_cos. */
-#define _GLIBCXX_HAVE___BUILTIN_COS 1
-
-/* Define if the compiler/host combination has __builtin_cosf. */
-#define _GLIBCXX_HAVE___BUILTIN_COSF 1
-
-/* Define if the compiler/host combination has __builtin_cosl. */
-#define _GLIBCXX_HAVE___BUILTIN_COSL 1
-
-/* Define if the compiler/host combination has __builtin_fabs. */
-#define _GLIBCXX_HAVE___BUILTIN_FABS 1
-
-/* Define if the compiler/host combination has __builtin_fabsf. */
-#define _GLIBCXX_HAVE___BUILTIN_FABSF 1
-
-/* Define if the compiler/host combination has __builtin_fabsl. */
-#define _GLIBCXX_HAVE___BUILTIN_FABSL 1
-
-/* Define if the compiler/host combination has __builtin_labs. */
-#define _GLIBCXX_HAVE___BUILTIN_LABS 1
-
-/* Define if the compiler/host combination has __builtin_sin. */
-#define _GLIBCXX_HAVE___BUILTIN_SIN 1
-
-/* Define if the compiler/host combination has __builtin_sinf. */
-#define _GLIBCXX_HAVE___BUILTIN_SINF 1
-
-/* Define if the compiler/host combination has __builtin_sinl. */
-#define _GLIBCXX_HAVE___BUILTIN_SINL 1
-
-/* Define if the compiler/host combination has __builtin_sqrt. */
-#define _GLIBCXX_HAVE___BUILTIN_SQRT 1
-
-/* Define if the compiler/host combination has __builtin_sqrtf. */
-#define _GLIBCXX_HAVE___BUILTIN_SQRTF 1
-
-/* Define if the compiler/host combination has __builtin_sqrtl. */
-#define _GLIBCXX_HAVE___BUILTIN_SQRTL 1
-
-/* Define to 1 if you have the `__signbit' function. */
-#define _GLIBCXX_HAVE___SIGNBIT 1
-
-/* Define to 1 if you have the `__signbitf' function. */
-#define _GLIBCXX_HAVE___SIGNBITF 1
-
-/* Define to 1 if you have the `__signbitl' function. */
-#define _GLIBCXX_HAVE___SIGNBITL 1
-
 /* Define as const if the declaration of iconv() needs const. */
 #define _GLIBCXX_ICONV_CONST 
 
@@ -973,14 +959,40 @@ _GLIBCXX_END_NAMESPACE
 /* Define to the version of this package. */
 #define _GLIBCXX_PACKAGE__GLIBCXX_VERSION "version-unused"
 
+/* The size of a `char', as computed by sizeof. */
+/* #undef SIZEOF_CHAR */
+
+/* The size of a `int', as computed by sizeof. */
+/* #undef SIZEOF_INT */
+
+/* The size of a `long', as computed by sizeof. */
+/* #undef SIZEOF_LONG */
+
+/* The size of a `short', as computed by sizeof. */
+/* #undef SIZEOF_SHORT */
+
+/* The size of a `void *', as computed by sizeof. */
+/* #undef SIZEOF_VOID_P */
+
 /* Define to 1 if you have the ANSI C header files. */
 #define STDC_HEADERS 1
 
 /* Version number of package */
 /* #undef _GLIBCXX_VERSION */
 
-/* Define if builtin atomic operations are supported on this host. */
-/* #undef _GLIBCXX_ATOMIC_BUILTINS */
+/* Define if builtin atomic operations for bool are supported on this host. */
+/* #undef _GLIBCXX_ATOMIC_BUILTINS_1 */
+
+/* Define if builtin atomic operations for short are supported on this host.
+   */
+/* #undef _GLIBCXX_ATOMIC_BUILTINS_2 */
+
+/* Define if builtin atomic operations for int are supported on this host. */
+/* #undef _GLIBCXX_ATOMIC_BUILTINS_4 */
+
+/* Define if builtin atomic operations for long long are supported on this
+   host. */
+/* #undef _GLIBCXX_ATOMIC_BUILTINS_8 */
 
 /* Define to use concept checking code from the boost libraries. */
 /* #undef _GLIBCXX_CONCEPT_CHECKS */
@@ -988,6 +1000,9 @@ _GLIBCXX_END_NAMESPACE
 /* Define if a fully dynamic basic_string is wanted. */
 /* #undef _GLIBCXX_FULLY_DYNAMIC_STRING */
 
+/* Define if gthreads library is available. */
+#define _GLIBCXX_HAS_GTHREADS 1
+
 /* Define to 1 if a full hosted library is built, or 0 if freestanding. */
 #define _GLIBCXX_HOSTED 1
 
@@ -1005,6 +1020,9 @@ _GLIBCXX_END_NAMESPACE
 /* Define if the compiler is configured for setjmp/longjmp exceptions. */
 /* #undef _GLIBCXX_SJLJ_EXCEPTIONS */
 
+/* Define if EOF == -1, SEEK_CUR == 1, SEEK_END == 2. */
+#define _GLIBCXX_STDIO_MACROS 1
+
 /* Define to use symbol versioning in the shared library. */
 #define _GLIBCXX_SYMVER 1
 
@@ -1043,6 +1061,10 @@ _GLIBCXX_END_NAMESPACE
    <tr1/cinttypes> in namespace std::tr1. */
 #define _GLIBCXX_USE_C99_INTTYPES_TR1 1
 
+/* Define if wchar_t C99 functions in <inttypes.h> should be imported in
+   <tr1/cinttypes> in namespace std::tr1. */
+#define _GLIBCXX_USE_C99_INTTYPES_WCHAR_T_TR1 1
+
 /* Define if C99 functions or macros in <math.h> should be imported in <cmath>
    in namespace std. */
 #define _GLIBCXX_USE_C99_MATH 1
@@ -1055,19 +1077,34 @@ _GLIBCXX_END_NAMESPACE
    namespace std::tr1. */
 #define _GLIBCXX_USE_C99_STDINT_TR1 1
 
+/* Defined if clock_gettime has monotonic clock support. */
+/* #undef _GLIBCXX_USE_CLOCK_MONOTONIC */
+
+/* Defined if clock_gettime has realtime clock support. */
+/* #undef _GLIBCXX_USE_CLOCK_REALTIME */
+
+/* Defined if gettimeofday is available. */
+#define _GLIBCXX_USE_GETTIMEOFDAY 1
+
 /* Define if LFS support is available. */
 #define _GLIBCXX_USE_LFS 1
 
 /* Define if code specialized for long long should be used. */
 #define _GLIBCXX_USE_LONG_LONG 1
 
+/* Defined if nanosleep is available. */
+/* #undef _GLIBCXX_USE_NANOSLEEP */
+
 /* Define if NLS translations are to be used. */
 /* #undef _GLIBCXX_USE_NLS */
 
-/* Define if dev/random and dev/urandom are available for the random_device of
-   TR1 (Chapter 5.1). */
+/* Define if /dev/random and /dev/urandom are available for the random_device
+   of TR1 (Chapter 5.1). */
 #define _GLIBCXX_USE_RANDOM_TR1 1
 
+/* Defined if sched_yield is available. */
+/* #undef _GLIBCXX_USE_SCHED_YIELD */
+
 /* Define if code specialized for wchar_t should be used. */
 #define _GLIBCXX_USE_WCHAR_T 1
 
@@ -1121,16 +1158,6 @@ _GLIBCXX_END_NAMESPACE
 # define ceill _ceill
 #endif
 
-#if defined (_GLIBCXX_HAVE__COPYSIGN) && ! defined (_GLIBCXX_HAVE_COPYSIGN)
-# define _GLIBCXX_HAVE_COPYSIGN 1
-# define copysign _copysign
-#endif
-
-#if defined (_GLIBCXX_HAVE__COPYSIGNL) && ! defined (_GLIBCXX_HAVE_COPYSIGNL)
-# define _GLIBCXX_HAVE_COPYSIGNL 1
-# define copysignl _copysignl
-#endif
-
 #if defined (_GLIBCXX_HAVE__COSF) && ! defined (_GLIBCXX_HAVE_COSF)
 # define _GLIBCXX_HAVE_COSF 1
 # define cosf _cosf
